@@ -85,7 +85,7 @@ void add_notification_action(GtkWindow *nw, const char *text, const char *key,
 void clear_notification_actions(GtkWindow *nw);
 void move_notification(GtkWidget *nw, int x, int y);
 void set_notification_timeout(GtkWindow *nw, glong timeout);
-void set_notification_hints(GtkWindow *nw, GHashTable *hints);
+void set_notification_hints(GtkWindow *nw, GVariant *hints);
 void notification_tick(GtkWindow *nw, glong remaining);
 
 #define STRIPE_WIDTH  32
@@ -453,12 +453,8 @@ create_notification(UrlClickedCb url_clicked)
 	windata->summary_label = gtk_label_new(NULL);
 	gtk_widget_show(windata->summary_label);
 	gtk_box_pack_start(GTK_BOX(vbox), windata->summary_label, FALSE, FALSE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (windata->summary_label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (windata->summary_label), 0.0);
-#else
-	gtk_misc_set_alignment(GTK_MISC(windata->summary_label), 0.0, 0.0);
-#endif
 	gtk_label_set_line_wrap(GTK_LABEL(windata->summary_label), TRUE);
 	gtk_label_set_line_wrap_mode (GTK_LABEL (windata->summary_label), PANGO_WRAP_WORD_CHAR);
 
@@ -467,12 +463,8 @@ create_notification(UrlClickedCb url_clicked)
 
 	windata->body_label = gtk_label_new(NULL);
 	gtk_box_pack_start(GTK_BOX(vbox), windata->body_label, FALSE, FALSE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (windata->body_label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (windata->body_label), 0.0);
-#else
-	gtk_misc_set_alignment(GTK_MISC(windata->body_label), 0.0, 0.0);
-#endif
 	gtk_label_set_line_wrap(GTK_LABEL(windata->body_label), TRUE);
 	gtk_label_set_line_wrap_mode (GTK_LABEL (windata->body_label), PANGO_WRAP_WORD_CHAR);
     gtk_label_set_max_width_chars (GTK_LABEL (windata->body_label), 50);
@@ -623,12 +615,8 @@ add_notification_action(GtkWindow *nw, const char *text, const char *key,
 	label = gtk_label_new(NULL);
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-#endif
 	buf = g_strdup_printf("<small>%s</small>", text);
 	gtk_label_set_markup(GTK_LABEL(label), buf);
 	g_free(buf);
@@ -689,20 +677,19 @@ set_notification_timeout(GtkWindow *nw, glong timeout)
 }
 
 /* Set notification hints */
-void
-set_notification_hints(GtkWindow *nw, GHashTable *hints)
+void set_notification_hints(GtkWindow *nw, GVariant *hints)
 {
 	WindowData *windata = g_object_get_data(G_OBJECT(nw), "windata");
-	GValue *value = NULL, *icon_value = NULL;
+	GVariant *value = NULL, *icon_value = NULL;
 
 	g_assert(windata != NULL);
 
-	value = (GValue *)g_hash_table_lookup(hints, "urgency");
-	icon_value = (GValue *)g_hash_table_lookup(hints, "action-icons");
+	g_variant_lookup(hints, "urgency", "v", &value);
+	g_variant_lookup(hints, "action-icons", "v", &icon_value);
 
-	if (value != NULL && G_VALUE_HOLDS_UCHAR(value))
+	if (value != NULL && g_variant_get_type(value) == G_VARIANT_TYPE_BYTE)
 	{
-		windata->urgency = g_value_get_uchar(value);
+		windata->urgency = g_variant_get_byte(value);
 
 		if (windata->urgency == URGENCY_CRITICAL) {
 			gtk_window_set_title(GTK_WINDOW(nw), "Critical Notification");
@@ -712,9 +699,9 @@ set_notification_hints(GtkWindow *nw, GHashTable *hints)
 	}
 
 	/* Determine if action-icons have been requested */
-	if (icon_value != NULL && G_VALUE_HOLDS_BOOLEAN(icon_value))
+	if (icon_value != NULL && g_variant_get_type(icon_value) == G_VARIANT_TYPE_BOOLEAN)
 	{
-		windata->action_icons = g_value_get_boolean(icon_value);
+		windata->action_icons = g_variant_get_boolean(icon_value);
 	}
 }
 
